<?php
/**
 * Manage Calameo Publications by Athlon
 * @Package WordPress
 * @Version: 1.1
 * @Author: Athlon Production <dev@athlonproduction.com>
 */
class AthlonCalameoManageConfiguration
{
    public static $PLUGIN = array(
        'title'                 => 'Athlon Manage Calameo Publications',
        'version'               => '1.1',
        'localization_domain'   => 'ath_mcp',
        'debug'                 => false,
        'options_name'          => array( 'calameo_credentials', 'calameo_subscription_ids' ),
    );

    public static $API = array(
        'get'    => array(
            'url'       => 'http://api.calameo.com/1.0/?',
            'action'    =>  '',
         ),
        'update' => array(
            'url'       => 'http://api.calameo.com/1.0/?',
            'action'    => 'API.updateBook',
        ),
        'delete' => array(
            'url'       => 'http://api.calameo.com/1.0/?',
            'action'    => 'API.deleteBook',
        ),
        'upload' => array(
            'url'       => 'http://upload.calameo.com/1.0/?',
            'action'    => 'API.publishFromUrl',
        ),
        'verify_account' => array(
            'url'       => 'http://api.calameo.com/1.0/?',
            'action'    => 'API.getAccountInfos',
        ),
        'subscriptions' => array(
            'url'       => 'http://api.calameo.com/1.0/?',
            'action'    => 'API.fetchAccountSubscriptions',
        ),
    );

    public static $WP_CALAMEO_NOT_INSTALLED_WARNING = "<p><strong>\"WP Calameo\" plugin is not installed.</strong></p><p>\"Athlon Manage Calameo Publications\" plugin requires that \"WP Calameo\" is installed in order to work properly. You can download it from <a href='http://wordpress.org/extend/plugins/wp-calameo/' target='_blank'>here</a></p>";

    public static $DB = array(
        'table_name'    => 'calameo_publications',
        'version'       => '1.0',
    );

    public static $SUPPORTED_DOCUMENTS = array(
        'mimetypes' => array(
            'application/msword',
            'application/rtf',
            'application/vnd.oasis.opendocument.presentation',
            'application/vnd.oasis.opendocument.presentation-template',
            'application/vnd.sun.xml.impress',
            'application/vnd.sun.xml.impress.template',
            'application/vnd.oasis.opendocument.spreadsheet',
            'application/vnd.oasis.opendocument.spreadsheet-template',
            'application/vnd.sun.xml.calc',
            'application/vnd.sun.xml.calc.template',
            'application/vnd.oasis.opendocument.text',
            'application/vnd.oasis.opendocument.text-template',
            'application/vnd.sun.xml.writer',
            'application/vnd.sun.xml.writer.template',
            'text/plain',
            'application/vnd.openxmlformats-officedocument.wordprocessingml.document',
            'application/vnd.ms-word.document.macroEnabled.12',
            'application/vnd.ms-excel',
            'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet',
            'application/vnd.ms-excel.sheet.macroEnabled.12',
            'application/vnd.ms-powerpoint',
            'application/vnd.openxmlformats-officedocument.presentationml.presentation',
            'application/vnd.ms-powerpoint.presentation.macroEnabled.12',
            'application/pdf',
        ),
    );

    public static $UI = array(
        'categories'    => array(
            'DESING',
            'BUSINESS',
            'AUTO',
            'CULTURE',
            'SCHOOL',
            'HEALTH',
            'HISTORY',
            'HUMOR',
            'LAW',
            'LITERATURE',
            'MISC',
            'MOVIES',
            'MUSIC',
            'NATURE',
            'NEWS',
            'POLITICS',
            'RELIGION',
            'SCIENCES',
            'SEXY',
            'PEOPLE',
            'SPORTS',
            'TECH',
            'TRAVEL',
            'VIDEOGAMES',
        ),
        'formats'       => array(
            'ALBUMS',
            'BD',
            'BOOKS',
            'BROCHURES',
            'CATALOGS',
            'COMICS',
            'MAGAZINES',
            'MANGAS',
            'MANUALS',
            'MISC',
            'MULTIMEDIA',
            'NEWSPAPERS',
            'NOVELS',
            'PRESENTATIONS',
            'REPORTS',
            'SHEETMUSIC',
        ),
        'dialects'      => array(
            'English'               => 'en',
            'French'                => 'fr',
            'German'                => 'de',
            'Spanish'               => 'es',
            'Italian'               => 'it',
            'Portuguese'            => 'pt',
            'Japanese'              => 'ja',
            'Chinese'               => 'zh',
            'Hindi'                 => 'hi',
            'Unknown'               => 'unknown',
            'Afar'                  => 'aa',
            'Abkhaze'               => 'ab',
            'Avestan'               => 'ae',
            'Afrikaans'             => 'af',
            'Amharic'               => 'am',
            'Aragonese'             => 'an',
            'Arabic'                => 'ar',
            'Assamese'              => 'as',
            'Avaric'                => 'av',
            'Aymara'                => 'ay',
            'Azerbaijani'           => 'az',
            'Bashkir'               => 'ba',
            'Belarusian'            => 'be',
            'Bulgarian'             => 'bg',
            'Bihari'                => 'bh',
            'Bislama'               => 'bi',
            'Bambara'               => 'bm',
            'Bengali'               => 'bn',
            'Tibetan'               => 'bo',
            'Breton'                => 'br',
            'Bosnian'               => 'bs',
            'Catalan'               => 'ca',
            'Chechen'               => 'ce',
            'Chamorro'              => 'ch',
            'Corsican'              => 'co',
            'Cree'                  => 'cr',
            'Czech'                 => 'cs',
            'Church Slavic'         => 'cu',
            'Chuvash'               => 'cv',
            'Welsh'                 => 'cy',
            'Danish'                => 'da',
            'Divehi'                => 'dv',
            'Dzongkha'              => 'dz',
            'Ewe'                   => 'ee',
            'Greek'                 => 'el',
            'Esperanto'             => 'eo',
            'Estonian'              => 'et',
            'Basque'                => 'eu',
            'Persian'               => 'fa',
            'Fulah'                 => 'ff',
            'Finnish'               => 'fi',
            'Fijian'                => 'fj',
            'Faroese'               => 'fo',
            'Western Frisian'       => 'fy',
            'Irish'                 => 'ga',
            'Scottish Gaelic'       => 'gd',
            'Galician'              => 'gl',
            'GuaranÃ­'              => 'gn',
            'Gujarati'              => 'gu',
            'Manx'                  => 'gv',
            'Hausa'                 => 'ha',
            'Hebrew'                => 'he',
            'Hiri Motu'             => 'ho',
            'Croatian'              => 'hr',
            'Haitian'               => 'ht',
            'Hungarian'             => 'hu',
            'Armenian'              => 'hy',
            'Herero'                => 'hz',
            'Interlingua'           => 'ia',
            'Indonesian'            => 'id',
            'Interlingue'           => 'ie',
            'Igbo'                  => 'ig',
            'Sichuan Yi'            => 'ii',
            'Inupiaq'               => 'ik',
            'Ido'                   => 'io',
            'Icelandic'             => 'is',
            'Inuktitut'             => 'iu',
            'Javanese'              => 'jv',
            'Georgian'              => 'ka',
            'Kongo'                 => 'kg',
            'Kikuyu'                => 'ki',
            'Kwanyama'              => 'kj',
            'Kazakh'                => 'kk',
            'Kalaallisut'           => 'kl',
            'Khmer'                 => 'km',
            'Kannada'               => 'kn',
            'Korean'                => 'ko',
            'Kanuri'                => 'kr',
            'Kashmiri'              => 'ks',
            'Kurdish'               => 'ku',
            'Komi'                  => 'kv',
            'Cornish'               => 'kw',
            'Kirghiz'               => 'ky',
            'Latin'                 => 'la',
            'Luxembourgish'         => 'lb',
            'Ganda'                 => 'lg',
            'Limburgish'            => 'li',
            'Lingala'               => 'ln',
            'Lao'                   => 'lo',
            'Lithuanian'            => 'lt',
            'Luba-Katanga'          => 'lu',
            'Latvian'               => 'lv',
            'Malagasy'              => 'mg',
            'Marshallese'           => 'mh',
            'Ma-ori'                => 'mi',
            'Macedonian'            => 'mk',
            'Malayalam'             => 'ml',
            'Mongolian'             => 'mn',
            'Moldavian'             => 'mo',
            'Marathi'               => 'mr',
            'Malay'                 => 'ms',
            'Maltese'               => 'mt',
            'Burmese'               => 'my',
            'Nauru'                 => 'na',
            'Norwegian BokmÃ¥l'     => 'nb',
            'North Ndebele'         => 'nd',
            'Nepali'                => 'ne',
            'Ndonga'                => 'ng',
            'Dutch'                 => 'nl',
            'Norwegian Nynorsk'     => 'nn',
            'Norwegian'             => 'no',
            'South Ndebele'         => 'nr',
            'Navajo'                => 'nv',
            'Chichewa'              => 'ny',
            'Occitan'               => 'oc',
            'Ojibwa'                => 'oj',
            'Oromo'                 => 'om',
            'Oriya'                 => 'or',
            'Ossetian'              => 'os',
            'Panjabi'               => 'pa',
            'Pa-li'                 => 'pi',
            'Polish'                => 'pl',
            'Pashto'                => 'ps',
            'Quechua'               => 'qu',
            'Raeto-Romance'         => 'rm',
            'Kirundi'               => 'rn',
            'Romanian'              => 'ro',
            'Russian'               => 'ru',
            'Kinyarwanda'           => 'rw',
            'Sanskrit'              => 'sa',
            'Sardinian'             => 'sc',
            'Sindhi'                => 'sd',
            'Northern Sami'         => 'se',
            'Sango'                 => 'sg',
            'Serbo-Croatian'        => 'sh',
            'Sinhalese'             => 'si',
            'Slovak'                => 'sk',
            'Slovenian'             => 'sl',
            'Samoan'                => 'sm',
            'Shona'                 => 'sn',
            'Somali'                => 'so',
            'Albanian'              => 'sq',
            'Serbian'               => 'sr',
            'Swati'                 => 'ss',
            'Sotho'                 => 'st',
            'Sundanese'             => 'su',
            'Swedish'               => 'sv',
            'Swahili'               => 'sw',
            'Tamil'                 => 'ta',
            'Telugu'                => 'te',
            'Tajik'                 => 'tg',
            'Thai'                  => 'th',
            'Tigrinya'              => 'ti',
            'Turkmen'               => 'tk',
            'Tagalog'               => 'tl',
            'Tswana'                => 'tn',
            'Tonga'                 => 'to',
            'Turkish'               => 'tr',
            'Tsonga'                => 'ts',
            'Tatar'                 => 'tt',
            'Twi'                   => 'tw',
            'Tahitian'              => 'ty',
            'Uighur'                => 'ug',
            'Ukrainian'             => 'uk',
            'Urdu'                  => 'ur',
            'Uzbek'                 => 'uz',
            'Venda'                 => 've',
            'Vietnamese'            => 'vi',
            'VolapÃ'                => 'vo',
            'Walloon'               => 'wa',
            'Wolof'                 => 'wo',
            'Xhosa'                 => 'xh',
            'Yiddish'               => 'yi',
            'Yoruba'                => 'yo',
            'Zhuang'                => 'za',
            'Zulu'                  => 'zu',
        ),

        'directions'    => array(
            'left to right',
            'right to left',
        ),

        'licenses'      => array(
            'pd'         => 'Public Domain',
            'by'         => 'Attribution',
            'by_nc'      => 'Attribution, NonCommercial',
            'by_nc_nd'   => 'Attribution, NonCommercial, NoDerivs',
            'by_nc_sa'   => 'Attribution, NonCommercial, ShareAlike',
            'by_nd'      => 'Attribution, NoDerivs',
            'by_sa'      => 'Attribution, ShareAlike',
        ),

        'skins'         => array(
            'cribd'         => 'http://sk.calameo.com/2.0/cribd/skin.xml',
            'default'       => 'http://sk.calameo.com/2.0/default/skin.xml',
            'interface'     => 'http://sk.calameo.com/2.0/interface/skin.xml',
            'black'         => 'http://sk.calameo.com/2.0/black/skin.xml',
            'simple'        => 'http://sk.calameo.com/2.0/simple/skin.xml',
        ),

        'comments' => array(
            'disabled',
            'moderate all',
            'moderate all except contacts',
            'accept only contacts',
            'accept all',
        ),

        'print_and_download_options' => array(
            'disabled',
            'only contacts',
            'everyone',
        ),

        'mode' => array(
            'viewer'    => 'Display the full publication',
            'mini'      => 'Display the mini version',
        ),

        'view' => array(
            'book',
            'slideshow',
            'scroll',
        ),

        'size' => array(
            'Small'     => array( 'width' => '300', 'height' => '194' ),
            'Medium'    => array( 'width' => '420', 'height' => '272' ),
            'Big'       => array( 'width' => '550', 'height' => '356' ),
        ),

        'clickto' => array(
            'embed'     => 'Open the publication directly in fullscreen',
            'public'    => 'Open the publication\'s overview page',
            'view'      => 'Open the publication\'s reading page',
        ),

        'clicktarget' => array(
            '_self'     => 'Open in the same window',
            '_blank'    => 'Open in a new window',
        ),

        'options' => array(
            'autoflip'          => 'Turn pages automatically',
            'showsharemenu'     => 'Show the share menu after reading',
            'hidelinks'         => 'Display the publication title',
        ),

        'error' => array(
            'message'   => 'Try again later!',
        ),
    );
}
?>